from pathlib import Path
import os
from injecta.dtype.classLoader import loadClass
from injecta.container.ContainerInterface import ContainerInterface
from pyfonybundles.appConfigLoader import loadAppConfig

def initAppContainer(appEnv: str) -> ContainerInterface:
    workingDir = Path(os.getcwd())

    appConfig = loadAppConfig(workingDir.joinpath('pyproject.toml'))
    containerInitConfig = appConfig['container-init']

    initContainerFunction = loadClass(containerInitConfig[0], containerInitConfig[1])

    return initContainerFunction(appEnv)



from pathlib import Path
import tomlkit

def loadAppConfig(pyprojectPath: Path) -> list:
    with pyprojectPath.open('r') as t:
        config = tomlkit.parse(t.read())

        if 'app' not in config:
            raise Exception('[app] section is missing in pyproject.toml')

        return config['app']
